===========
srclicenser
===========


.. image:: https://img.shields.io/pypi/v/srclicenser.svg
        :target: https://pypi.python.org/pypi/srclicenser

.. image:: https://img.shields.io/travis/starofrainnight/srclicenser.svg
        :target: https://travis-ci.org/starofrainnight/srclicenser

.. image:: https://readthedocs.org/projects/srclicenser/badge/?version=latest
        :target: https://srclicenser.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/starofrainnight/srclicenser/shield.svg
     :target: https://pyup.io/repos/github/starofrainnight/srclicenser/
     :alt: Updates


A tool that make sure there have a license header at top of source files


* Free software: Apache License 2.0
* Documentation: https://srclicenser.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `PyPackageTemplate`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`PyPackageTemplate`: https://github.com/audreyr/cookiecutter-pypackage

